@@ -151,10 +151,10 @@ class SingleFormulaBasedMaterial:
 
         mesh.rezero()
         if save:
-            if type(save)==str:
-                self._model=save+'_'+self._model
-            
-            loc='STL/'+self._model
+
+            from time import strftime
+            stamp = strftime("%m_%d_%H_%M")
+            loc='STL/'+self._model+'_'+stamp
             os.makedirs(loc, exist_ok=True)
             with open(loc+'/info.txt','w') as f:
                 print('Formula: {}'.format(self.__formula), file=f)
@@ -188,9 +188,6 @@ class SingleFormulaBasedMaterial:
         
         mesh = trimesh.base.Trimesh(vertices=verts, faces=faces)
         if save:
-            if type(save)==str:
-                self._model=save+'_'+self._model
-            
             loc='STL/'+self._model
             os.makedirs(loc, exist_ok=True)
             with open(loc+'/info_surface.txt','w') as f:
@@ -237,4 +234,4 @@ if __name__=='__main__':
         print('The formula-based material with {} and eps {} does not exist. Please try again.'.format(test.get_formula(), test.get_eps()))
 
     
-    
\ No newline at end of file
+    
